ProxyBuilder

Struct ProxyBuilder 

pub struct ProxyBuilder { /* private fields */ }
A builder for Proxy

Implementations

Source

impl ProxyBuilder

pub fn new() -> Self

Create a new builder

pub fn with_database(self, database: Database) -> Self

Set the database with a pre-made adapter

pub fn with_sqlite_pool(self, pool: SqlitePool) -> Self

Use this SQLite database

pub fn with_postgres_pool(self, pool: PgPool) -> Self

Use this PostgreSQL database pool

pub fn load_config_from_database(self, load: bool) -> Self

Load configuration for custom providers, aliases, and API keys from the database. If a database pool is provided, this defaults to true.

pub fn log_to_database(self, log: bool) -> Self

Enable or disable logging to the database. Logging requires with_database to have been called.

pub fn with_config(self, config: ProxyConfig) -> Self

Merge this configuration into the current one.

pub async fn with_config_from_path( self, path: &Path, ) -> Result<Self, Report<Error>>

Read a configuration file from this path and merge it into the current configuration.

pub fn with_alias(self, alias: AliasConfig) -> Self

Add an AliasConfig to the Proxy

pub fn with_aliases(self, aliases: Vec<AliasConfig>) -> Self

Add multiple AliasConfig objects to the Proxy

pub fn with_api_key(self, key: ApiKeyConfig) -> Self

Add an ApiKeyConfig to the proxy

pub fn with_api_keys(self, keys: Vec<ApiKeyConfig>) -> Self

Add multiple ApiKeyConfig objects to the proxy

pub fn with_custom_provider(self, config: CustomProviderConfig) -> Self

Add a custom provider to the list of providers

pub fn with_custom_providers(self, configs: Vec<CustomProviderConfig>) -> Self

Add multiple custom providers to the list of providers

pub fn with_provider(self, provider: Arc<dyn ChatModelProvider>) -> Self

Add a precreated provider to the list of providers. This can be used to create your own custom providers that require capabilities not provided by the CustomProviderConfig.

pub fn with_openai(self, token: Option<String>) -> Self

Enable the OpenAI provider, if it was disabled by [without_default_providers]

pub fn with_anyscale(self, token: Option<String>) -> Self

Enable the Anyscale provider, if it was disabled by [without_default_providers]

pub fn with_anthropic(self, token: Option<String>) -> Self

Enable the Anthropic provider, if it was disabled by [without_default_providers]

pub fn with_aws_bedrock(self, client: Option<Client>) -> Self

Enable the AWS Bedrock provider, possibly passing a custom client.

pub fn with_deepinfra(self, token: Option<String>) -> Self

Enable the DeepInfra provider, if it was disabled by [without_default_providers]

pub fn with_fireworks(self, token: Option<String>) -> Self

Enable the Fireworks provider, if it was disabled by [without_default_providers]

pub fn with_groq(self, token: Option<String>) -> Self

Enable the Groq provider, if it was disabled by [without_default_providers]

pub fn with_mistral(self, token: Option<String>) -> Self

Enable the Mistral provider, if it was disabled by [without_default_providers]

pub fn with_together(self, token: Option<String>) -> Self

Enable the Together provider, if it was disabled by [without_default_providers]

pub fn with_ollama(self, url: Option<String>) -> Self

Enable the Ollama provider, if it was disabled by [without_default_providers]

pub fn without_default_providers(self) -> Self

Don’t load the default providers

pub fn user_agent(self, user_agent: impl Into<String>) -> Self

Set the user agent that will be used for HTTP requests. This only applies if with_client is not used.

pub fn with_client(self, client: Client) -> Self

Supply a custom reqwest::Client that the proxy will use to make requests.

pub async fn build(self) -> Result<Proxy, Report<Error>>

Build the proxy from the supplied options.