pub struct AliasConfig {
pub name: String,
pub random_order: bool,
pub models: Vec<AliasConfigProvider>,
}Expand description
An alias configuration mape a single name to a list of provider-model pairs
Fields
name: StringA name for this alias
random_order: boolIf true, start from a random provider. If false, always start with the first provider, and only use later providers on retry.
models: Vec<AliasConfigProvider>The providers and models that this alias represents.