pub struct CollectedProxiedResult {
pub body: SingleChatResponse,
pub info: ResponseInfo,
pub provider: String,
}Expand description
A response from the model provider, collected into a single body if it was streamed
Fields
body: SingleChatResponseThe response itself
info: ResponseInfoOther information about the response
provider: StringThe provider which was used for the successful response.