pub enum Error {
Show 15 variants
UnknownProvider(String),
NoDefault(String),
NoAliasProvider(String, String),
AliasEmpty(String),
NoAliasApiKey(String, String),
NoApiKey(String),
ModelNotSpecified,
ModelError,
MissingApiKey,
MissingApiKeyEnv(String, String),
ResultParseError,
ReadingConfig,
LoadingDatabase,
ReadingHeader(String, &'static str),
MissingStreamInformation(&'static str),
}Expand description
Proxy errors
Variants
UnknownProvider(String)
A specified model provider was not found
NoDefault(String)
No provider was specified, and no default could be inferred from the model name
NoAliasProvider(String, String)
An alias references a provider that doesn’t exist
AliasEmpty(String)
An alias does not reference any models
NoAliasApiKey(String, String)
An alias references an API key that doesn’t exist
NoApiKey(String)
The requested API key does not exist
ModelNotSpecified
The request is missing the model name
ModelError
The model provider returned an error
MissingApiKey
The API key was not provided
MissingApiKeyEnv(String, String)
The environment variable for the API key was not found
ResultParseError
Failed to parse the model provider’s output
ReadingConfig
Failed to read the configuration file
LoadingDatabase
Failed to load data from the database
ReadingHeader(String, &'static str)
Failed to parse a header value
MissingStreamInformation(&'static str)
A required piece of information was missing from the response stream