pub struct ResponseInfo {
pub meta: Option<Value>,
pub model: String,
}Expand description
Metadata about the response, from the provider.
Fields
meta: Option<Value>Any other metadata from the provider that should be logged.
model: StringThe model used for the request, as returned by the provider.