pub struct ToolCall {
pub index: Option<usize>,
pub id: Option<String>,
pub typ: Option<String>,
pub function: ToolCallFunction,
}Expand description
Represents a call to a tool by the OpenAI model
Fields
index: Option<usize>The optional index of the tool call
id: Option<String>The optional ID of the tool call
typ: Option<String>The optional type of the tool call, typically “function”
function: ToolCallFunctionThe function details of the tool call