pub struct OpenAiRequestFormatOptions {
pub transforms: ChatRequestTransformation<'static>,
}Fields
transforms: ChatRequestTransformation<'static>Trait Implementations
Sourceimpl Clone for OpenAiRequestFormatOptions
impl Clone for OpenAiRequestFormatOptions
Sourcefn clone(&self) -> OpenAiRequestFormatOptions
fn clone(&self) -> OpenAiRequestFormatOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpenAiRequestFormatOptions
impl Debug for OpenAiRequestFormatOptions
Sourceimpl Default for OpenAiRequestFormatOptions
impl Default for OpenAiRequestFormatOptions
Sourcefn default() -> OpenAiRequestFormatOptions
fn default() -> OpenAiRequestFormatOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OpenAiRequestFormatOptions
impl<'de> Deserialize<'de> for OpenAiRequestFormatOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OpenAiRequestFormatOptions
impl JsonSchema for OpenAiRequestFormatOptions
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl Eq for OpenAiRequestFormatOptions
impl StructuralPartialEq for OpenAiRequestFormatOptions