Module request

Module request 

Utilities for retrying a provider request as needed.

Structs

RetryOptions
TryModelChoicesError
TryModelChoicesResult

Enums

RepeatBackoffBehavior
How to increase the backoff duration as additional retries occur.

Functions

parse_response_json
Parse a JSON response, with informative errors when the format does not match the expected structure.
response_is_sse
send_standard_request
Send an HTTP request with retries, and handle errors. Most providers can use this to handle sending their request and handling errors.
try_model_choices
Run a provider request and retry on failure.