pub enum RepeatBackoffBehavior {
Constant,
Additive {
amount: Duration,
},
Exponential {
multiplier: f64,
},
}Expand description
How to increase the backoff duration as additional retries occur.
Variants
Constant
Use the initial backoff duration for additional retries as well.
Additive
Add this duration to the backoff duration after each retry.
Exponential
Multiply the backoff duration by this value after each retry.