pub struct CustomProviderConfig {
pub name: String,
pub label: Option<String>,
pub url: String,
pub api_key: Option<String>,
pub api_key_source: Option<String>,
pub format: ProviderRequestFormat,
pub headers: BTreeMap<String, String>,
pub prefix: Option<String>,
}Expand description
A declarative definition of a model provider
Fields
name: StringThe name of the provider, as referenced in proxy requests
label: Option<String>A human-readable name for the provider
url: StringThe url to use
api_key: Option<String>The API token to pass along
api_key_source: Option<String>Where to retrieve the value for api_key.
If api_key_source is “env” then api_key is an environment variable.
If it is empty, then api_key is assumed to be the token itself, if provided.
In the future the key sources will be pluggable, to support external secret sources.
format: ProviderRequestFormatWhat kind of request format this provider uses. Defaults to OpenAI-compatible
headers: BTreeMap<String, String>Extra headers to pass with the request
prefix: Option<String>Models starting with this prefix will use this provider by default.
Implementations
Sourceimpl CustomProviderConfig
impl CustomProviderConfig
Sourcepub fn into_provider(self, client: Client) -> CustomProvider
pub fn into_provider(self, client: Client) -> CustomProvider
Generate a CustomProvider object from the configuration
Sourcepub fn with_token_or_env(self, token: Option<String>, env: &str) -> Self
pub fn with_token_or_env(self, token: Option<String>, env: &str) -> Self
Add an API token to the CustomProviderConfig, or if one is not provided, then configure it to read from the given environment variable.