Utilities for retrying a provider request as needed.
Structs
Enums
- Repeat
Backoff Behavior - How to increase the backoff duration as additional retries occur.
Functions
- parse_
response_ json - Parse a JSON response, with informative errors when the format does not match the expected structure.
- response_
is_ sse - send_
standard_ request - Send an HTTP request with retries, and handle errors. Most providers can use this to handle sending their request and handling errors.
- try_
model_ choices - Run a provider request and retry on failure.